# Getting your organization started with Zulip

Use this as a checklist to get your organization off to a great start.

## Organization settings

* Set a policy for [who can join the organization](/help/manage-who-can-join-and-invite).

* Configure [allowed authentication methods](/help/configure-authentication-methods).

* Add an organization [icon and description](/help/create-your-organization-profile) to
  customize your login/registration pages as well as how your
  organization appears in the desktop and mobile apps.

* Do a [quick review](/help/review-your-organization-settings)
  of all the organization settings available.

## Create streams

Most messages in Zulip are sent to streams. Streams are similar to chat
rooms, email lists, and IRC/Slack channels, in that they determine who
receives a message. A few important notes:

* It's often better to start with fewer streams, and let the number of
  streams grow organically. For small teams, you can start with the default
  streams and iterate from there.

* For very large organizations, we recommend using a consistent naming
  scheme, like `#marketing/<name>` or `#mk/<name>` for all streams
  pertaining to the marketing team, `#help/<team name>` for
  `<team name>`'s internal support stream, etc.

* Add clear descriptions to your streams.

Some relevant help articles are

* [Create a stream](/help/create-a-stream)

* [Set the default streams](/help/set-default-streams-for-new-users)
  for new members.

* [Rename a stream](/help/rename-a-stream)

## Understand topics

Zulip’s topics are life-changing, but it can take a bit of time for everyone
to learn how to use them effectively. It helps a lot if there are at least a
few people who understand the conversation model at the beginning.

* Read our [guide to streams and topics](/help/about-streams-and-topics),
  and send it out to a few people who you think would be good stewards of
  the organization.

* If you're unsure at all, create an account on the
  [Zulip community server](https://chat.zulip.org) and see what topics look
  like there.

## Set up integrations

Zulip integrates directly with dozens of products, and hundreds more through
[Zapier](/integrations/doc/zapier) and [IFTTT](/integrations/doc/ifttt).

The [integrations page](/integrations) has instructions for integrating with
each product.

## Familiarize yourself with Zulip’s featureset

As the administrator of your Zulip organization, you'll be the initial
expert teaching other users how to use Zulip.

* [Review your settings](/help/review-your-settings), and skim the article
  names here on the left sidebar.

* Learn the basic [keyboard shortcuts](/help/keyboard-shortcuts) (`n`, `r`, `c`, and `End`).

* Bonus: learn [Markdown message formatting](/help/format-your-message-using-markdown).

* If anything is confusing or feels missing, tweet `@zulip`, ask on the
  [Zulip community server](https://chat.zulip.org), or email
  [support@zulipchat.com](mailto:support@zulipchat.com). We love hearing
  from new administrators!

## Invite users and onboard your community

* [Delete any test messages](/help/edit-or-delete-a-message#delete-a-message-completely)
  you want to delete.
* Use the `#zulip` stream to answer questions and share tips on how to use
  Zulip effectively.
* If you have an existing chat tool, make sure everyone knows that the
  team is switching, and why. The team should commit to use Zulip
  exclusively **for at least a week** to make an effective trial;
  stragglers will result in everyone having a bad experience.
* If [community topic edits](/help/community-topic-edits) are enabled,
  encourage a few people to help rename topics for the first few days, while
  everyone is still getting used to the new conversation model.

## Bonus things to setup

* [Add custom profile fields](/help/add-custom-profile-fields)
- [Automatically linkify](/help/add-a-custom-linkification-filter)
  issue numbers.
- [Write custom integrations](/api/integrations-overview)
  for your team’s workflow.
- If your users primarily speak a language other than English,
  [set a default language for your organization](/help/change-the-default-language-for-your-organization).
- [Add custom emoji](/help/add-custom-emoji), at the very least for
  your organization's logo.
- Link to your Zulip instance with a [nice badge](/help/join-zulip-chat-badge).
- [Delete](/help/delete-a-topic) embarrassing test messages before sending invites.
- Send feedback to the Zulip development community!  We love hearing
  about problems (however minor) and feature ideas that could make
  Zulip even better.
